Struct QueryResultsSyntaxError
pub struct QueryResultsSyntaxError(SyntaxErrorKind);Available on crate feature
rdf only.Expand description
An error in the syntax of the parsed file.
Tuple Fields
0: SyntaxErrorKindImplementations
impl QueryResultsSyntaxError
impl QueryResultsSyntaxError
pub fn location(&self) -> Option<Range<TextPosition>>
pub fn location(&self) -> Option<Range<TextPosition>>
The location of the error inside of the file.