WriterSolutionsSerializer

Struct WriterSolutionsSerializer 

pub struct WriterSolutionsSerializer<W>
where W: Write,
{ formatter: WriterSolutionsSerializerKind<W>, }
Available on crate feature rdf only.
Allows writing query results into a Write implementation.

Could be built using a QueryResultsSerializer.

Do not forget to run the finish method to properly write the last bytes of the file.

This writer does unbuffered writes. You might want to use BufWriter to avoid that.

Example in TSV (the API is the same for JSON, XML and CSV):

use oxrdf::{LiteralRef, Variable, VariableRef};
use sparesults::{QueryResultsFormat, QueryResultsSerializer};
use std::iter::once;

let tsv_serializer = QueryResultsSerializer::from_format(QueryResultsFormat::Tsv);
let mut buffer = Vec::new();
let mut serializer = tsv_serializer.serialize_solutions_to_writer(
    &mut buffer,
    vec![Variable::new("foo")?, Variable::new("bar")?],
)?;
serializer.serialize(once((VariableRef::new("foo")?, LiteralRef::from("test"))))?;
serializer.finish()?;
assert_eq!(buffer, b"?foo\t?bar\n\"test\"\t\n");

Fields

formatter: WriterSolutionsSerializerKind<W>

Implementations



impl<W> WriterSolutionsSerializer<W>
where W: Write,

pub fn serialize<'a>( &mut self, solution: impl IntoIterator<Item = (impl Into<VariableRef<'a>>, impl Into<TermRef<'a>>)>, ) -> Result<(), Error>

Writes a solution.

Example in JSON (the API is the same for XML, CSV and TSV):

use sparesults::{QueryResultsFormat, QueryResultsSerializer, QuerySolution};
use oxrdf::{Literal, LiteralRef, Variable, VariableRef};
use std::iter::once;

let json_serializer = QueryResultsSerializer::from_format(QueryResultsFormat::Json);
let mut buffer = Vec::new();
let mut serializer = json_serializer.serialize_solutions_to_writer(&mut buffer, vec![Variable::new("foo")?, Variable::new("bar")?])?;
serializer.serialize(once((VariableRef::new("foo")?, LiteralRef::from("test"))))?;
serializer.serialize(&QuerySolution::from((vec![Variable::new("bar")?], vec![Some(Literal::from("test").into())])))?;
serializer.finish()?;
assert_eq!(buffer, br#"{"head":{"vars":["foo","bar"]},"results":{"bindings":[{"foo":{"type":"literal","value":"test"}},{"bar":{"type":"literal","value":"test"}}]}}"#);

pub fn finish(self) -> Result<W, Error>

Writes the last bytes of the file.